@@ -7,6 +7,8 @@
 //! The `bevy_rapier` projects implements two other crates `bevy_rapier2d` and `bevy_rapier3d` which
 //! defines physics plugins for the Bevy game engine.
 //!
+//! User documentation for `bevy_rapier` is on [the official Rapier site](https://rapier.rs/docs/).
+//!
 
 // #![deny(missing_docs)] // FIXME: deny this
 
@@ -23,6 +25,7 @@ pub mod physics;
 pub mod render;
 
 pub mod prelude {
+    pub use super::physics::wrapper::*;
     pub use super::physics::{
         ColliderBundle, ColliderComponentsSet, ColliderPositionSync, IntoEntity, IntoHandle,
         JointBuilderComponent, NoUserData, PhysicsHooksWithQuery, PhysicsHooksWithQueryObject,
